/*
* Jalview - A Sequence Alignment Editor and Viewer
* Copyright (C) 2005 AM Waterhouse, J Procter, G Barton, M Clamp, S Searle
*
* This program is free software; you can redistribute it and/or
* modify it under the terms of the GNU General Public License
* as published by the Free Software Foundation; either version 2
* of the License, or (at your option) any later version.
*
* This program is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
* GNU General Public License for more details.
*
* You should have received a copy of the GNU General Public License
* along with this program; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
*/
package jalview.bin;

import java.io.*;

import java.util.*;
import java.util.jar.*;


public class Cache {
    public static String VERSION = "Release 2.0";
    public static String BUILD_DATE = "";
    public static Properties applicationProperties;

    // Current properties include:
    //
    // LAST_DIRECTORY   , use this to cache record of where the user looked to find a file
    // UNIPROT_CACHE
    // USER_DEFINED_COLOUR - file describing last user set colours
    // FONT_NAME
    // FONT_STYLE
    // FONT_SIZE
    // logs.Axis.Level - one of the stringified Levels for log4j controlling the logging level for axis (used for web services)
    // jalview.browser - used in the jalview.utils.browserLauncher class if it doesn't know what else to do.
    public static void loadProperties() {
        // get last build time.
        long date = 0;

        try {
            String localFile = Cache.class.getProtectionDomain().getCodeSource()
                                          .getLocation().toString();
            localFile = localFile.concat("!/");

            String tmpString = "jar:";
            String localJarFileString = tmpString.concat(localFile);
            java.net.URL localJarFileURL = new java.net.URL(localJarFileString);
            java.net.JarURLConnection localJarFile = (java.net.JarURLConnection) localJarFileURL.openConnection();
            date = localJarFile.getLastModified();
        } catch (Exception ex) {
            ex.printStackTrace();
        }

        if (date == 0) {
            // this is called for unpackaged class files, ie not in a Jar file
            // InstallAnywhere version will find build date this way
            // not entirely accurate as it only tells you when Cache.class was last compiled
            java.io.File f = new java.io.File(System.getProperty("user.dir") +
                    "/jalview/bin/Cache.class");
            date = f.lastModified();
        }

        if (date != 0) {
            BUILD_DATE = new Date(date).toString();
        }

        applicationProperties = new Properties();

        try {
            FileInputStream in = new FileInputStream(System.getProperty(
                        "user.home") + "/.jalview_properties");
            applicationProperties = new Properties();
            applicationProperties.load(in);
            in.close();
        } catch (Exception ex) {
        }
    }

    public static String getProperty(String key) {
        return applicationProperties.getProperty(key);
    }

    public static String setProperty(String key, String obj) {
        try {
            FileOutputStream out = new FileOutputStream(System.getProperty(
                        "user.home") + "/.jalview_properties");

            applicationProperties.setProperty(key, obj);

            applicationProperties.store(out, "---JalviewX Properties File---");
            out.close();
        } catch (Exception ex) {
        }

        return obj;
    }
}
